/* MOUSE.H
 * Mouse.C Declarations and structures
 */

typedef struct {
			int X,Y,Buttons,Count;
		} MPos;

typedef struct {
		unsigned ScreenMask [16];
		unsigned CursorMask [16];
		int XSpot,YSpot;
	} Curs;

/* Only checks if Mouse is present */
int MouseOpen (void);
/* Resets the driver;
 * If the driver or the mouse can't be initialized returns 0,
 * otherwise it returns the number of buttons in the mouse */
int MoReset (void);
/* Increments the internal mouse flag and if it is 0 then
 * shows the cursor */
void MoShowCursor (void);
/* Decrements the internal mouse flag and removes the cursor.
 * Remember that multiple calls to thi function must be balanced
 * by an equal number of calls to MoShowCursor.
 * Always hide the cursor prior to draw anything on the screen */
void MoHideCursor (void);
/* Puts in Pos structure current mouse position and button status
 * Count is always set to 0 */
void MoGetMousePos (MPos *Pos);
/* Sets Mouse Current Cursor Position */
void MoSetMousePos (int x,int y);
/* Puts in Pos structure current mouse position and button status
 * Count is always set to the number of presses for the selected button
 * since the last call to this function
 * The returned position is relative to the last press */
void MoGetPressInfo (MPos *Pos,int button);
/* Puts in Pos structure current mouse position and button status
 * Count is set to the number of releases for the selected button
 * since the last call to this function
 * The returned position is relative to the last Release */
void MoGetRelInfo (MPos *Pos,int button);
/* Sets the minimum and maximum horizontl position.
 * The mouse cursor can't be moved outside that range */
void MoSetHorRange (int min,int max);
/* Sets the minimum and maximum vertical position.
 * The mouse cursor can't be moved outside that range */
void MoSetVerRange (int min,int max);
/* Set the graphics cursor to that defined by the 'cursor' parameter */
void MoSetGrCursor (Curs *cursor);
/* Defines the text cursor mode and shape.
 * Hw defines if you use hardware (1) or Software (0) cursor type.
 * If hardware cursor is selected the following parameters are
 * Start (SMask) and Stop (CMask) lines for the cursor.
 * If Software is selected, SMask is the Screen Mask parameter and
 * CMask is the Cursor Mask Parameter. */
void MoSetTextCur (int Hw,int SMask, int CMask);
/* Returns in Pos the motion counters (in 'mikey' units) from
 * the previous call to this function.
 * Buttons and Count are always 0 */
void MoMotionCnt (MPos *Pos);
/* This call installs a routine that is called by the driver under
 * certain conditions.
 * Parameter mask is a bit mask. The bits are:
 *		0 -> Cursor Position Changes
 *		1 -> Left Button Pressed
 *		2 -> Left Button Released
 *		3 -> Right Button Pressed
 *		4 -> Right Button Released
 * And rout is the address of the 'action' routine.
 * This routine receives some data in its registers :
 * 		AX -> Conditions (as defined in the mask)
 *		BX -> Button State
 *		CX -> Cursor X
 *		DX -> Cursot Y
 */
void MoSetRespRout (void (*rout) (void),int mask);
/* Turns Light Pen Emulation ON */
void MoLPEmu (void);
/* Turns Light Pen Emulation Off */
void MoLPNoEmu (void);
/* Sets the ratio between phisical (mikey) motion units and logical
 * (pixel) motion units both for x and y directions */
void MoSetRatio (int XRatio,int YRatio);
